@@ -1,4 +1,4 @@
-"survBayes.b.fctn.Lambda.quad.d" <-
+`survBayes.b.fctn.Lambda.quad.d` <-
 function (nth, time, time.int, time.int.mat, hr, int, int.delta, 
     BB.int, BB.time, KK, taylor.int, taylor.time) 
 {
@@ -15,3 +15,4 @@ function (nth, time, time.int, time.int.mat, hr, int, int.delta,
     weighted.Lambda.ind <- (interval.part + rest.part)
     return(sum(hr * weighted.Lambda.ind))
 }
+
