@@ -1,4 +1,4 @@
-"survBayes.control.lognormal.frailty" <-
+`survBayes.control.lognormal.frailty` <-
 function (sigma.RE = 100, rate.sigma.clust = 1e-04, shape.sigma.clust = 1e-04) 
 {
     if (sigma.RE < 0) 
@@ -11,3 +11,4 @@ function (sigma.RE = 100, rate.sigma.clust = 1e-04, shape.sigma.clust = 1e-04)
         shape.sigma.clust = shape.sigma.clust, sigma.RE.miss = missing(sigma.RE), 
         rate.sigma.clust.miss = missing(rate.sigma.clust), shape.sigma.clust.miss = missing(shape.sigma.clust))
 }
+
